# Copyright 2015-2023 Province of British Columbia
# Copyright 2021 Environment and Climate Change Canada
# Copyright 2023-2024 Australian Government Department of Climate Change, 
# Energy, the Environment and Water
#
#    Licensed under the Apache License, Version 2.0 (the "License");
#    you may not use this file except in compliance with the License.
#    You may obtain a copy of the License at
#
#       https://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS,
#    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#    See the License for the specific language governing permissions and
#    limitations under the License.

test_that("logLik", {
  fits <- ssd_fit_dists(ssddata::ccme_boron)
  expect_equal(logLik(fits), c(
    gamma = -116.81515869884, lgumbel = -120.092975580318, llogis = -118.507435324864,
    lnorm = -117.514216489547, lnorm_lnorm = -115.179384580908, weibull = -116.81264387617
  ))
})
